@@ -1,9 +1,9 @@
 from dataclasses import dataclass
-from typing import List, Optional
+from typing import Optional
 
 from .InstallmentOption import InstallmentOption
 
 
 @dataclass(kw_only=True)
 class PaymentProduct3391SpecificOutput:
-    installmentOptions: Optional[List[InstallmentOption]] = None
+    installmentOptions: Optional[list[InstallmentOption]] = None
